// in src/App.js
import * as React from "react";
import { Admin, Resource } from 'react-admin';
import { CategoryList, CategoryShow, CategoryCreate, CategoryEdit } from './components/category';
import { StoreList, StoreShow, StoreCreate, StoreEdit } from './components/store';
import { OfferList, OfferShow, OfferCreate, OfferEdit } from './components/offer';
import { BannerList, BannerShow, BannerCreate, BannerEdit } from './components/banner';
import { UserList, UserShow, UserEdit } from './components/user';
import categoryIcon from '@material-ui/icons/Category';
import storeIcon from '@material-ui/icons/Shop';
import offerIcon from '@material-ui/icons/LocalOffer';
import userIcon from '@material-ui/icons/Person';
import bannerIcon from '@material-ui/icons/Slideshow';
import MyLayout from './Mylayout';

import {
  FirebaseAuthProvider,
  FirebaseDataProvider,
} from 'react-admin-firebase';

import {FIREBASE_CONFIG, THEME, DISABLE_DEMO } from './config/constant';

const firebaseOptions = { logging: false,};
const dataProvider = FirebaseDataProvider(FIREBASE_CONFIG, firebaseOptions);
const authProvider = FirebaseAuthProvider(FIREBASE_CONFIG, firebaseOptions);
// Use this just like the normal auth provider
const myAuthProvider = {
  // Copy all authprovider functionality
  ...authProvider,
  // Wrap the login and check for custom claims
  login: async (params) => {
  const user = await authProvider.login(params);
  const data = await dataProvider.getOne('permissions', { id: user.user.uid });
  console.log(data.data);  
  const isAdmin = data.data.is_admin;
    if (isAdmin) {
      return user;
    }
    await authProvider.logout()
    throw new Error("Login error, you don't have admin permission");
  },
  getIdentity: async () => {
    try {
            const { id, fullName, avatar } = JSON.parse(localStorage.getItem('auth'));
            return Promise.resolve({ id, fullName, avatar });
        } catch (error) {
        }
  }
};

const App = () => (
 <Admin 
 theme={THEME} 
 layout={MyLayout} 
 title='Deals Admin Panel' 
 dataProvider={dataProvider} 
 authProvider={myAuthProvider} >
    <Resource 
      name="category"
      list={CategoryList}
      show={CategoryShow}
      create={CategoryCreate}
      edit={CategoryEdit}
      icon={categoryIcon}
    />
    <Resource
      name="store"
      list={StoreList}
      show={StoreShow}
      create={StoreCreate}
      edit={StoreEdit}
      icon={storeIcon}
    />
    <Resource
      name="offer"
      list={OfferList}
      show={OfferShow}
      create={OfferCreate}
      edit={OfferEdit}
      icon={offerIcon}
    />

    <Resource
      name="banner"
      list={BannerList}
      show={BannerShow}
      create={BannerCreate}
      edit={BannerEdit}
      icon={bannerIcon}
    />
    
    <Resource
      name="users"
      list={UserList}
      show={UserShow}
      edit={UserEdit}
      icon={userIcon}
    />

  </Admin>
);

export default App;