import * as React from "react";
import { Fragment } from 'react';
import {
  Datagrid,
  List,
  Show,
  Create,
  Edit,
  Filter,
  DateField,
  ImageField,
  ImageInput,
  BooleanInput,
  SimpleShowLayout,
  SimpleForm,
  TextField,
  TextInput,
  ShowButton,
  EditButton,
  DeleteButton,
  BooleanField,
  required,
  BulkDeleteButton
} from "react-admin";
import {DISABLE_DEMO} from '../config/constant';

const BannerFilter = (props) => (
  <Filter {...props}>
    <TextInput label="Search" source="title" alwaysOn />
  </Filter>
);

const BulkActionButtons = props => (
  (DISABLE_DEMO) ? '':<Fragment>
      {/* default bulk delete action */}
     <BulkDeleteButton {...props} />
  </Fragment>
);

export const BannerList = (props) => (
  <List
    {...props}
    filters={<BannerFilter />}
    bulkActionButtons = {<BulkActionButtons />}
  >
    <Datagrid>
      <TextField source="title" label="Title"/>
      <TextField source="heading" label="Heading"/>
      <TextField source="subheading" label="Sub Heading"/>
      <BooleanField source="is_active" label="Active"/>
      <BooleanField source="is_image" label="Banner"/>
      <TextField source="updatedby" label="Updated By"/>
      <DateField source="lastupdate" label="Updated At"/>
      <ShowButton label="" />
      <EditButton disabled={DISABLE_DEMO} label="" />
      <DeleteButton disabled={DISABLE_DEMO} />
    </Datagrid>
  </List>
);

export const BannerShow = (props) => (
  <Show {...props}>
    <SimpleShowLayout>
    <TextField source="id" label="ID"/>
      <TextField source="title" label="Title"/>
      <TextField source="heading" label="Heading"/>
      <TextField source="subheading" label="Sub Heading"/>
      <ImageField source="image.src" label="Image"/>
      <TextField source="image.title" label="Image Name"/>
      <BooleanField source="is_active" label="Active"/>
      <BooleanField source="is_image" label="Image Banner (True) or Text Banner"/>
      <TextField source="updatedby" label="Updated By"/>
      <DateField source="lastupdate" label="Updated At"/>
    </SimpleShowLayout>
  </Show>
);

export const BannerCreate = (props) => (
  (DISABLE_DEMO) ? <h1>'You can't create banner in demo mode'</h1>:
  <Create {...props}>
    <SimpleForm>
      <TextInput source="title" label="Title" validate={[required()]}/>
      <TextInput source="heading" label="Heading" validate={[required()]}/>
      <TextInput source="subheading" label="Sub Heading" validate={[required()]}/>
      <ImageInput source="image" label="Image" accept="image/*">
            <ImageField source="src" title="title" validate={[required()]}/>
    </ImageInput>
    <TextInput source="url" label="URL" validate={[required()]}/>
    <BooleanInput source="is_active" label="Active"/>
    <BooleanInput source="is_image" label="Image Banner (True) or Text Banner"/>
    </SimpleForm>
  </Create>
);

export const BannerEdit = (props) => (
  <Edit {...props}>
    <SimpleForm>
    <TextInput source="title" label="Title" validate={[required()]}/>
      <TextInput source="heading" label="Heading" validate={[required()]}/>
      <TextInput source="subheading" label="Sub Heading" validate={[required()]}/>
      <ImageInput source="image" label="Image" accept="image/*">
            <ImageField source="src" title="src" validate={[required()]}/>
    </ImageInput>
    <TextInput source="url" label="URL" validate={[required()]}/>
    <BooleanInput source="is_active" label="Active"/>
    <BooleanInput source="is_image" label="Image Banner (True) or Text Banner"/>
    </SimpleForm>
  </Edit>
);
