import * as React from "react";
import {
  Datagrid,
  List,
  Show,
  Create,
  Edit,
  Filter,
  DateField,
  ImageField,
  ImageInput,
  BooleanInput,
  SimpleShowLayout,
  SimpleForm,
  TextField,
  TextInput,
  ShowButton,
  EditButton,
  DeleteButton,
  BooleanField,
  required,
  BulkDeleteButton
} from "react-admin";
import {DISABLE_DEMO} from '../config/constant';
import { Fragment } from 'react';

const CategoryFilter = (props) => (
  <Filter {...props}>
    <TextInput label="Search" source="title" alwaysOn />
  </Filter>
);
const BulkActionButtons = props => (
  (DISABLE_DEMO) ? '':<Fragment>
      {/* default bulk delete action */}
     <BulkDeleteButton {...props} />
  </Fragment>
);

export const CategoryList = (props) => (
  <List
    {...props}
    filters={<CategoryFilter />}
    bulkActionButtons = {<BulkActionButtons />}
  >
    <Datagrid>
      <TextField source="title" label="Title"/>
      <TextField source="slug" label="Slug"/>
      <BooleanField source="is_active" label="Active"/>
      <TextField source="updatedby" label="Updated By"/>
      <DateField source="lastupdate" label="Updated At"/>
      <ShowButton label="" />
      <EditButton disabled={DISABLE_DEMO} label="" />
      <DeleteButton disabled={DISABLE_DEMO} label="" />
    </Datagrid>
  </List>
);

export const CategoryShow = (props) => (
  <Show {...props}>
    <SimpleShowLayout>
      <TextField source="title" label="Title"/>
      <TextField source="slug" label="Slug"/>
      <ImageField source="image.src" label="Image"/>
      <TextField source="image.title" label="Image Name"/>
      <BooleanField source="is_active" label="Active"/>
      <TextField source="updatedby" label="Updated By"/>
      <DateField source="lastupdate" label="Updated At"/>
    </SimpleShowLayout>
  </Show>
);

export const CategoryCreate = (props) => (
  (DISABLE_DEMO) ? <h1>'You can't create categories in demo mode'</h1>:
  <Create {...props}>
    <SimpleForm>
      <TextInput source="title" label="Title" validate={[required()]}/>
      <TextInput source="slug" label="Slug" validate={[required()]}/>
      <ImageInput source="image" label="Image" accept="image/*" validate={[required()]}>
            <ImageField source="src" title="src" />
    </ImageInput>
    <BooleanInput source="is_active" label="Active"/>
    </SimpleForm>
  </Create>
);

export const CategoryEdit = (props) => (
  <Edit {...props}>
    <SimpleForm>
    <TextInput source="title" label="Title" validate={[required()]}/>
      <TextInput source="slug" label="Slug" validate={[required()]}/>
      <ImageInput source="image" label="Image" accept="image/*" validate={[required()]}>
            <ImageField source="src" title="src"/>
    </ImageInput>
    <BooleanInput source="is_active" label="Active"/>
    </SimpleForm>
  </Edit>
);