import * as React from "react";
import {
    Datagrid,
    List,
    Show,
    Create,
    Edit,
    Filter,
    DateField,
    ImageField,
    ImageInput,
    SelectInput,
    BooleanInput,
    ReferenceInput,
    SimpleShowLayout,
    SimpleForm,
    TextField,
    TextInput,
    ShowButton,
    EditButton,
    DeleteButton,
    BooleanField,
    DateTimeInput,
    SelectField,
    UrlField,
    ReferenceField,
    required,
    BulkDeleteButton
} from "react-admin";
import RichTextInput from "ra-input-rich-text";
import {DISABLE_DEMO} from '../config/constant';
import { Fragment } from 'react';

const OfferFilter = (props) => (
    <Filter {...props}>
        <TextInput label="Search" source="title" alwaysOn />
    </Filter>
);

const BulkActionButtons = props => (
    (DISABLE_DEMO) ? '':<Fragment>
        {/* default bulk delete action */}
       <BulkDeleteButton {...props} />
    </Fragment>
  );

export const OfferList = (props) => (
    <List
        {...props}
        filters={<OfferFilter />}
        bulkActionButtons = {<BulkActionButtons />}
    >
        <Datagrid>
            <TextField source="title" label="Title" />
            <SelectField source="type" label="Type" choices={[
                { id: 'c', name: 'Coupon' },
                { id: 'd', name: 'Deal' },
            ]} />
            <BooleanField source="is_active" label="Active" />
            <BooleanField source="is_exclusive" label="Exclusive" />
            <BooleanField source="is_verified" label="Verified" />
            <BooleanField source="is_featured" label="Featured" />
            <DateField source="expire_at" label="Expiry" />
            <TextField source="updatedby" label="Updated By" />
            <DateField source="lastupdate" label="Updated At" />
            <ShowButton label="" />
            <EditButton disabled={DISABLE_DEMO} label="" />
            <DeleteButton disabled={DISABLE_DEMO} label="" />
        </Datagrid>
    </List>
);

export const OfferShow = (props) => (
    <Show {...props}>
        <SimpleShowLayout>
            <TextField source="title" label="Title" />
            <TextField source="slug" label="Slug" />
            <TextField source="description" label="Description" />
            <SelectField source="type" label="Type" choices={[
                { id: 'c', name: 'Coupon' },
                { id: 'd', name: 'Deal' },
            ]} />
            <ImageField source="image.src" label="Image" />
            <TextField source="image.title" label="Image Name" />
            <BooleanField source="is_active" label="Active" />
            <BooleanField source="is_exclusive" label="Exclusive" />
            <BooleanField source="is_verified" label="Verified" />
            <BooleanField source="is_featured" label="Featured" />
            <TextField source="discount" label="Discount" />
            <TextField source="price" label="Price" />
            <UrlField source="url" label="Affiliate URL" />
            <ReferenceField label="Category"
                source="category_id"
                reference="category">
                <TextField source="title" />
            </ReferenceField>
            <ReferenceField label="Store"
                source="store_id"
                reference="store">
                <TextField source="title" />
            </ReferenceField>
            <DateField source="expire_at" label="Expiry" />
            <TextField source="updatedby" label="Updated By" />
            <DateField source="lastupdate" label="Updated At" />
        </SimpleShowLayout>
    </Show>
);

// rating, reviews
export const OfferCreate = (props) => (
    (DISABLE_DEMO) ? <h1>'You can't create Offers in demo mode'</h1>:
    <Create {...props}>
        <SimpleForm>
            <TextInput source="title" label="Title" validate={[required()]}/>
            <TextInput source="slug" label="Slug" validate={[required()]}/>
            <RichTextInput source="description" label="Description" validate={[required()]}/>
            <SelectInput source="type" label="Type" choices={[
                { id: 'c', name: 'Coupon' },
                { id: 'd', name: 'Deal' },
            ]} validate={[required()]}/>
            <ImageInput source="image" label="Image" accept="image/*">
                <ImageField source="src" title="src" validate={[required()]}/>
            </ImageInput>
            <TextInput source="code" label="Code" />
            <BooleanInput source="is_active" label="Active" />
            <BooleanInput source="is_exclusive" label="Exclusive" />
            <BooleanInput source="is_verified" label="Verified" />
            <BooleanInput source="is_featured" label="Featured" />
            <TextInput source="discount" label="Discount" />
            <TextInput source="price" label="Price" />
            <TextInput source="url" label="Affiliate URL" validate={[required()]}/>
            <ReferenceInput
                label="Category"
                source="category_id"
                reference="category"
            >
                <SelectInput label="Category" optionText="title" validate={[required()]}/>
            </ReferenceInput>
            <ReferenceInput
                label="Store"
                source="store_id"
                reference="store"
            >
                <SelectInput label="store" optionText="title" validate={[required()]}/>
            </ReferenceInput>
            <DateTimeInput source="expire_at" label="Expiry" validate={[required()]}/>
        </SimpleForm>
    </Create>
);

export const OfferEdit = (props) => (
    <Edit {...props}>
        <SimpleForm>
            <TextInput source="title" label="Title" validate={[required()]}/>
            <TextInput source="slug" label="Slug" validate={[required()]}/>
            <RichTextInput source="description" label="Description" validate={[required()]}/>
            <SelectInput source="type" label="Type" choices={[
                { id: 'c', name: 'Coupon' },
                { id: 'd', name: 'Deal' },
            ]} validate={[required()]}/>
            <ImageInput source="image" label="Image" accept="image/*">
                <ImageField source="src" title="title" validate={[required()]}/>
            </ImageInput>
            <TextInput source="code" label="Code" />
            <BooleanInput source="is_active" label="Active" />
            <BooleanInput source="is_exclusive" label="Exclusive" />
            <BooleanInput source="is_verified" label="Verified" />
            <BooleanInput source="is_featured" label="Featured" />
            <TextInput source="discount" label="Discount" />
            <TextInput source="price" label="Price" />
            <TextInput source="url" label="Affiliate URL" validate={[required()]}/>
            <ReferenceInput
                label="Category"
                source="category_id"
                reference="category"
            >
                <SelectInput label="Category" optionText="title" validate={[required()]}/>
            </ReferenceInput>
            <ReferenceInput
                label="Store"
                source="store_id"
                reference="store"
            >
                <SelectInput label="store" optionText="title" validate={[required()]}/>
            </ReferenceInput>
            <DateTimeInput source="expire_at" label="Expiry" validate={[required()]}/>
        </SimpleForm>
    </Edit>
);