import * as React from "react";
import {
  Datagrid,
  List,
  Show,
  Create,
  Edit,
  Filter,
  DateField,
  ImageField,
  ImageInput,
  BooleanInput,
  SimpleShowLayout,
  SimpleForm,
  TextField,
  TextInput,
  ShowButton,
  EditButton,
  DeleteButton,
  BooleanField,
  UrlField,
  required,
  BulkDeleteButton
} from "react-admin";
import {DISABLE_DEMO} from '../config/constant';
import { Fragment } from 'react';

const StoreFilter = (props) => (
  <Filter {...props}>
    <TextInput label="Search" source="title" alwaysOn />
  </Filter>
);
const BulkActionButtons = props => (
  (DISABLE_DEMO) ? '':<Fragment>
      {/* default bulk delete action */}
     <BulkDeleteButton {...props} />
  </Fragment>
);


export const StoreList = (props) => (
  <List
    {...props}
    filters={<StoreFilter />}
    bulkActionButtons = {<BulkActionButtons />}
  >
    <Datagrid>
    <TextField source="title" label="Title"/>
      <TextField source="slug" label="Slug"/>
      <BooleanField source="is_active" label="Active"/>
      <BooleanField source="is_featured" label="Featured"/>
      <UrlField source="store_url" label="Store Website"/>
      <TextField source="updatedby" label="Updated By"/>
      <DateField source="lastupdate" label="Updated At"/>
      <ShowButton label="" />
      <EditButton disabled={DISABLE_DEMO} label="" />
      <DeleteButton disabled={DISABLE_DEMO} label="" />
    </Datagrid>
  </List>
);

export const StoreShow = (props) => (
  <Show {...props}>
    <SimpleShowLayout>
      <TextField source="title" label="Title"/>
      <TextField source="slug" label="Slug"/>
      <ImageField source="image.src" label="Image"/>
      <TextField source="image.title" label="Image Name"/>
      <BooleanField source="is_active" label="Active"/>
      <BooleanField source="is_featured" label="Featured"/>
      <UrlField source="store_url" label="Store Website"/>
      <TextField source="updatedby" label="Updated By"/>
      <DateField source="lastupdate" label="Updated At"/>
    </SimpleShowLayout>
  </Show>
);

export const StoreCreate = (props) => (
  (DISABLE_DEMO) ? <h1>'You can't create Stores in demo mode'</h1>:
  <Create {...props}>
    <SimpleForm validate={validateForm}>
      <TextInput source="title" validate={[required()]}/>
      <TextInput source="slug" validate={[required()]}/>
      <ImageInput source="image" label="Image" accept="image/*" validate={[required()]}>
            <ImageField source="src" title="title"/>
    </ImageInput>
    <BooleanInput source="is_active" />
    <BooleanInput source="is_featured" />
    <TextInput source="store_url" validate={[required()]}/>
    </SimpleForm>
  </Create>
);

export const StoreEdit = (props) => (
  <Edit {...props}>
    <SimpleForm>
    <TextInput source="title" validate={[required()]}/>
      <TextInput source="slug" validate={[required()]}/>
      <ImageInput source="image" label="Image" accept="image/*" validate={[required()]}>
            <ImageField source="src" title="title"/>
    </ImageInput>
    <BooleanInput source="is_active" />
    <BooleanInput source="is_featured" />
    <TextInput source="store_url" validate={[required()]}/>
    </SimpleForm>
  </Edit>
);

const validateForm = (values) => {
    const errors = {};
    if (!isUrlValid(values.store_url)) {
        errors.store_url = ['The Store URL is invalid'];
    }
    return errors
};

const isUrlValid = (str) => {
    var pattern = new RegExp('^(https?:\\/\\/)?'+ // protocol
      '((([a-z\\d]([a-z\\d-]*[a-z\\d])*)\\.)+[a-z]{2,}|'+ // domain name
      '((\\d{1,3}\\.){3}\\d{1,3}))'+ // OR ip (v4) address
      '(\\:\\d+)?(\\/[-a-z\\d%_.~+]*)*'+ // port and path
      '(\\?[;&a-z\\d%_.~+=-]*)?'+ // query string
      '(\\#[-a-z\\d_]*)?$','i'); // fragment locator
    return !!pattern.test(str);
  }
